import { Construct } from 'constructs';
export interface ServiceLinkedRoleProps {
    /**
     * The service principal for the AWS service to which this role is attached.
     *
     * You use a string similar to a URL but without the http:// in front. For example: elasticbeanstalk.amazonaws.com .
     *
     * Service principals are unique and case-sensitive. To find the exact service principal for your service-linked role, see AWS services that work with IAM in the IAM User Guide. Look for the services that have Yes in the Service-Linked Role column. Choose the Yes link to view the service-linked role documentation for that service.
     * https://docs.aws.amazon.com/IAM/latest/UserGuide/using-service-linked-roles.html
     */
    readonly awsServiceName: string;
    /**
     * The description of the role. This is only used when creating a new role.
     * When there is an existing role for the aws service, this field is ignored.
     *
     * @default no description
     */
    readonly description?: string;
}
export declare class ServiceLinkedRole extends Construct {
    constructor(scope: Construct, id: string, props: ServiceLinkedRoleProps);
}
